@@ -20,7 +20,7 @@ use warnings;
 
 use Image::Magick;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =head2 new( )
 
@@ -49,6 +49,11 @@ sub resize {
     my $image = $self->load( $file );
 
     $image->Scale( Geometry => $size . "x$size" );
+    $image->Extent(
+        Geometry   => $size . "x$size",
+        gravity    => 'center',
+        background => 'none'
+    );
 
     return $image->ImageToBlob( magick => 'png' );
 }
@@ -99,7 +104,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2009 by Brian Cassidy
+Copyright 2003-2013 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
